"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express = require("express");
const proxy_1 = require("./proxy");
exports.ProxyRouter = proxy_1.ProxyRouter;
const db_1 = require("./db");
exports.DatabaseRouter = db_1.DatabaseRouter;
const api_1 = require("./api");
exports.ApiRouter = api_1.ApiRouter;
const static_1 = require("./static");
const routerMap = {
    proxy: proxy_1.ProxyRouter,
    api: api_1.ApiRouter,
    database: db_1.DatabaseRouter,
    static: static_1.StaticRouter
};
const MockServer = function (config) {
    const app = express();
    let configs = [];
    let type;
    for (type in config) {
        if (config.hasOwnProperty(type)) {
            let conf = config[type];
            let item = conf && {
                priority: conf.priority || 0,
                type: type,
                config: conf,
                router: routerMap[type]
            };
            if (conf) {
                configs.push({
                    priority: conf.priority || 0,
                    type: type,
                    config: conf,
                    router: routerMap[type]
                });
            }
        }
    }
    configs.sort((a, b) => a.priority > b.priority ? 1 : (a.priority === b.priority ? 0 : -1));
    for (const item of configs) {
        app.use(item.router(item.config));
    }
    return app;
};
exports.MockServer = MockServer;
exports.default = MockServer;
